/*
  Simple MPI program

  Jim Teresco
  Department of Computer Science
  Williams College

  Created: Fall 2000

  Modified Tue Jun 18 22:00:33 EDT 2002

  $Id: mpihello.c,v 1.1 2002/06/19 02:36:11 terescoj Exp $
*/

/* include the MPI header file for function prototypes and other
   information needed by MPI */
#include <mpi.h>

/* include standard I/O for printf */
#include <stdio.h>

/* for gethostbyname, getpid */
#include <netdb.h>
#include <stdlib.h>

/* The main program will need the argc, argv arguments to be passed on
   to MPI_Init() */
int main(int argc, char *argv[]) {
  int numprocs;
  int rank;
  int rc;
  char hostname[MAXHOSTNAMELEN];
  int pid;

  /* Initialize MPI.  Pass a reference to the command line to allow MPI
     to take any arguments it needs */
  rc=MPI_Init(&argc,&argv);
  /* It's always good to check the return values on MPI calls */
  if (rc!=MPI_SUCCESS) fprintf(stderr,"MPI_Init faled\n");

  /* Get the number of processes and the rank of this process */
  MPI_Comm_size(MPI_COMM_WORLD, &numprocs);
  MPI_Comm_rank(MPI_COMM_WORLD, &rank);

  /* let's see who we are to the "outside world" - what host and what PID */
  gethostname(hostname,MAXHOSTNAMELEN);
  pid = getpid();
  
  /* say who we are */
  printf("Rank %d of %d has pid %5d on %s\n",rank,numprocs,pid,hostname);
  fflush(stdout);

  /* allow MPI to clean up after itself */
  MPI_Finalize();
  return 0;
}
